@@ -14,11 +14,11 @@ BEGIN
 {
 	package Type::Tie;
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.006';
+	our $VERSION   = '0.008';
 	our @ISA       = qw( Exporter::Tiny );
 	our @EXPORT    = qw( ttie );
 	
-	sub ttie (\[$@%]$;@)#>&%*/&<%\$[]^!@;@)
+	sub ttie (\[$@%]@)#>&%*/&<%\$[]^!@;@)
 	{
 		my ($ref, $type, @vals) = @_;
 		
@@ -45,7 +45,7 @@ BEGIN
 {
 	package Type::Tie::BASE;
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.006';
+	our $VERSION   = '0.008';
 	
 	BEGIN {
 		my $impl;
@@ -115,8 +115,14 @@ BEGIN
 		
 		my @vals = map {
 			my $val = $coerce ? $coerce->($_) : $_;
-			Carp::croak(sprintf "%s does not meet type constraint %s", _dd($_), $TYPE{$self})
-				unless $check->($val);
+			if (not $check->($val)) {
+				my $type = $TYPE{$self};
+				Carp::croak(
+					$type && $type->can('get_message')
+						? $type->get_message($val)
+						: sprintf("%s does not meet type constraint %s", _dd($_), $type||'Unknown')
+				);
+			}
 			$val;
 		} (my @cp = @_);  # need to copy @_ for Perl < 5.14
 		
@@ -128,7 +134,7 @@ BEGIN
 {
 	package Type::Tie::ARRAY;
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.006';
+	our $VERSION   = '0.008';
 	our @ISA       = qw( Tie::StdArray Type::Tie::BASE );
 	
 	sub TIEARRAY
@@ -169,7 +175,7 @@ BEGIN
 {
 	package Type::Tie::HASH;
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.006';
+	our $VERSION   = '0.008';
 	our @ISA       = qw( Tie::StdHash Type::Tie::BASE );
 	
 	sub TIEHASH
@@ -191,7 +197,7 @@ BEGIN
 {
 	package Type::Tie::SCALAR;
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.006';
+	our $VERSION   = '0.008';
 	our @ISA       = qw( Tie::StdScalar Type::Tie::BASE );
 	
 	sub TIESCALAR
@@ -310,6 +316,11 @@ L<Type::Tiny|Type::Tiny::Manual>
 Please report any bugs to
 L<http://rt.cpan.org/Dist/Display.html?Queue=Type-Tie>.
 
+=head1 SUPPORT
+
+B<< IRC: >> support is available through in the I<< #moops >> channel
+on L<irc.perl.org|http://www.irc.perl.org/channels.html>.
+
 =head1 SEE ALSO
 
 L<Type::API>,
@@ -323,7 +334,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013 by Toby Inkster.
+This software is copyright (c) 2013-2014 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
